@@ -1,12 +1,12 @@
+import os
+import time
+
+import numpy as np
+import pytest
+
 import cvxpy as cp
 from cvxpy.reductions.dcp2cone.cone_matrix_stuffing import ConeMatrixStuffing
 from cvxpy.tests.base_test import BaseTest
-import pytest
-import numpy as np
-
-import os
-import time
-import unittest
 
 
 def benchmark(func, iters: int = 1, name=None) -> None:
@@ -20,7 +20,6 @@ def benchmark(func, iters: int = 1, name=None) -> None:
         name, np.mean(vals), np.std(vals), iters))
 
 
-@unittest.skip('skip benchmarks on windows')
 class TestBenchmarks(BaseTest):
     def test_diffcp_sdp_example(self) -> None:
 
